@@ -1,7 +1,9 @@
 from sys import exit, argv
+
 import toml
 
 import py2dmat
+import py2dmat.mpi
 
 
 def main():
@@ -19,10 +21,14 @@ def main():
     args = parser.parse_args()
 
     file_name = args.inputfile
-    info = py2dmat.Info(toml.load(file_name))
-    algname = info.algorithm["name"]
+    inp = {}
+    if py2dmat.mpi.rank() == 0:
+        inp = toml.load(file_name)
+    if py2dmat.mpi.size() > 1:
+        inp = py2dmat.mpi.comm().bcast(inp, root=0)
+    info = py2dmat.Info(inp)
 
-    # Define algorithm
+    algname = info.algorithm["name"]
     if algname == "mapper":
         from .algorithm.mapper_mpi import Algorithm
     elif algname == "minsearch":
@@ -37,7 +43,14 @@ def main():
 
     solvername = info.solver["name"]
     if solvername == "surface":
-        from .solver.surface import Solver
+        if py2dmat.mpi.rank() == 0:
+            print(
+                'WARNING: solver name "surface" is deprecated and will be unavailable in future.'
+                ' Use "sim-trhepd-rheed" instead.'
+            )
+        from .solver.sim_trhepd_rheed import Solver
+    elif solvername == "sim-trhepd-rheed":
+        from .solver.sim_trhepd_rheed import Solver
     elif solvername == "analytical":
         from .solver.analytical import Solver
     else:
@@ -45,6 +58,6 @@ def main():
         exit(1)
 
     solver = Solver(info)
-    runner = py2dmat.Runner(solver)
+    runner = py2dmat.Runner(solver, info)
     alg = Algorithm(info, runner)
     alg.main()
